#include "QtGUI1.h"

QtGUI1::QtGUI1(QString file, QWidget *parent) :
    QMainWindow(parent)
{
    menuBar = new QMenuBar();
    this->setMenuBar(menuBar);

    /* create menus for menuBar */
    QAction *openAct = new QAction(tr("&Open File"), this);
    openAct->setShortcuts(QKeySequence::Open);
    openAct->setStatusTip(tr("Open A Existing File"));
    connect(openAct, &QAction::triggered, this, &QtGUI1::OpenFile);

    /* Adding actions to QMenu */
    fileMenu = menuBar->addMenu(tr("&File"));
    fileMenu->addAction(openAct);

    this->setGeometry(100, 100, 500, 700);

    CBtops = new QComboBox(this);
    CBtops->setGeometry(10,25,150,50);

    LBextents = new QLabel(this);
    LBextents->setGeometry(10, 100, 500, 30);

    if(file != "") { filePath = file; LoadTops(); }

    connect(CBtops, SIGNAL(currentIndexChanged(int)), this, SLOT(LoadExtends()));
}


void QtGUI1::OpenFile()
{
    filePath = QFileDialog::getOpenFileName(this, tr("Open g database"), "/usr/brlcad/share/db/", tr(""));
    LoadTops();
}


void QtGUI1::LoadTops()
{
    database = new BRLCAD::ConstDatabase();

    database->Load(filePath.toStdString().c_str());
    BRLCAD::ConstDatabase::TopObjectIterator tops = database->FirstTopObject();

    CBtops->clear();

    while(tops.Good())
    {
        CBtops->addItem(tops.Name());
        tops.operator ++();
    }

    this->setWindowTitle(database->Title());
}

void QtGUI1::LoadExtends()
{
    database->UnSelectAll();

    database->Select(
                CBtops->currentText().toStdString().c_str() );


    double * min = database->BoundingBoxMinima().coordinates;
    double * max = database->BoundingBoxMaxima().coordinates;

    LBextents->setText( QString::number(max[0] - min[0]) + "x" + QString::number(max[1] - min[1]) + "x" + QString::number(max[2] - min[2]));
}


